<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>Tiledについて</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation type="unfinished">プロパティ</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Save map before executing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>最近使ったファイル(&amp;R)</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>マップ(&amp;M)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">レイヤー(&amp;L)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>メインツールバー</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>貼り付け(&amp;P)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>Tiledについて(&amp;A)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>Qtについて</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>マップのサイズを変更(&amp;R)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>マップの設定(&amp;P)...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>グリッドの表示(&amp;G)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>ファイル名をつけて保存(&amp;A)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation>新しいファイル(&amp;N)...</translation>
    </message>
    <message>
        <location line="+98"/>
        <source>&amp;Export As...</source>
        <translation>名前をつけてエクスポート(&amp;E)...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>拡張タイルセットを追加(&amp;A)...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">レイヤーの順番を上げる(&amp;U)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation type="obsolete">Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">レイヤーの順番を下げる(&amp;n)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation type="obsolete">Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">すべて選択(&amp;A)</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">すべて選択解除(&amp;N)</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">新しいファイル...</translation>
    </message>
    <message>
        <location line="-113"/>
        <source>New &amp;Tileset...</source>
        <translation>新しいタイルセット(&amp;T)...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">レイヤーを削除(&amp;R)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">タイル・レイヤーを追加(&amp;T)...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">オブジェクト・レイヤーの追加(&amp;O)...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">レイヤーの複製(&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+D</source>
        <translation type="obsolete">Ctrl+Shift+D</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">レイヤーの設定(&amp;P)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>拡大</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>拡大リセット</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Save As Image...</source>
        <translation>画像で保存...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Cu&amp;t</source>
        <translation>切り取り(&amp;t)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>マップをずらす(&amp;O)...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>対象となるレイヤーのすべてをずらします</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>設定(&amp;f)...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>最近使ったファイルをクリア</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">複製(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">削除(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">プロパティ(&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">オブジェクトを複製(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">オブジェクトを削除(&amp;R)</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">オブジェクトのプロパティ(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
        <source>Not a map file.</source>
        <translation type="unfinished">マップファイルではありません。</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation type="unfinished">タイルセットファイルではありません。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation type="unfinished">%3

行 %1, 位置 %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation type="unfinished">ファイルは見つかりませんでした: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation type="unfinished">読み込めませんでした: %1</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="unfinished">マップの回転がサポートされていないものです: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="unfinished">タイルセットのパラメータが不正です &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="unfinished">タイルセットを読み込み中のエラーが発生しました &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation type="unfinished">タイルのIDが不正です: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="unfinished">タイルセットの画像を読み込み中にエラーが発生しました:
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="unfinished">&lt;tile&gt; 要素が多すぎます</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+66"/>
        <location line="+39"/>
        <location line="+103"/>
        <source>Invalid tile: %1</source>
        <translation type="unfinished">不正なタイル: %1</translation>
    </message>
    <message>
        <location line="-188"/>
        <source>Unknown encoding: %1</source>
        <translation type="unfinished">エンコーディングがよく分かりません: %1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="unfinished">&apos;%1&apos;という圧縮方法には対応していません</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="unfinished">レイヤー &apos;%1&apos; のデータが壊れています</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="unfinished">レイヤー &apos;%3&apos;の(%1,%2)のタイルをパースできません</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="unfinished">グローバル・タイルIDが不正です (0未満): %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile used but no tilesets specified</source>
        <translation type="unfinished">タイルセットが指定されていません</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">書き込み用ファイルを開けませんでした.</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>新しいマップ</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>マップの大きさ</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>タイルの大きさ</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>マップ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>種類:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>□が並んだマップ</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>◇が並んだマップ</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>新しいタイルセット</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>タイルセット</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>名前(&amp;N):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>画像:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>参照(&amp;B)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>透過色を設定する:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>タイル</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>タイルの幅:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>上左の余白:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>タイルの高さ:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>タイル間の余白:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>種類:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>場所</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>大きさ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>マップのオフセット</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>マップのずらし方</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>右端を左へ回転</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>対象レイヤー:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>表示中のすべてのレイヤー</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>すべてのレイヤー</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>選択されたレイヤー</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>範囲:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>マップ全体</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>選択部分のみ</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>保存と読み込み</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>レイヤーデータの保持方法(&amp;S):</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (未圧縮)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (gzip圧縮)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (zlib圧縮)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation>CSV</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>タイルセットの画像が変更された時、再読み込みする(&amp;R)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>エクスターナルDTDはXMLパーサーで問題が起こる可能性があるため、デフォルトではオフになっています。</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>マップを保存するときDTDリファレンスを入れる(&amp;D)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>インターフェース</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>表示言語(&amp;L):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>リサイズ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>大きさ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>オフセット（ずらす）</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>画像で保存</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>場所</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>参照(&amp;B)...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>表示レイヤーのみ(&amp;v)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>現在表示している拡大率(&amp;z)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>タイルのグリッドを描画(&amp;D)</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">書き込み用ファイルを開けませんでした.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+115"/>
        <source>No ruleRegions layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+208"/>
        <source>Tile</source>
        <translation type="unfinished">タイル</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+491"/>
        <source>No set layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Apply AutoMap rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>塗りつぶし</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
        <source>Execute Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+39"/>
        <location line="+61"/>
        <source>Error Executing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-60"/>
        <source>You do not have any commands setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Edit Commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>There was an error running the command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
        <source>Open in text editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+90"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+100"/>
        <source>Name</source>
        <translation type="unfinished">名前</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
        <source>Edit Commands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+111"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>消しゴム</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
        <source>Layers</source>
        <translation>レイヤー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>透過度:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>レイヤー</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">プロパティ...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
        <location line="+10"/>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <location line="-9"/>
        <location line="+8"/>
        <source>Redo</source>
        <translation>やり直す</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">マップを開くときにエラーが発生しました</translation>
    </message>
    <message>
        <location line="+391"/>
        <source>Open Map</source>
        <translation>マップを開く</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+79"/>
        <source>Tiled map files (*.tmx)</source>
        <translation></translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">マップを保存中にエラーが発生しました</translation>
    </message>
    <message>
        <location line="-425"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <location line="+962"/>
        <source>&amp;Layer</source>
        <translation>レイヤー(&amp;L)</translation>
    </message>
    <message>
        <location line="-711"/>
        <source>Error Opening Map</source>
        <translation>マップを開いている途中にエラー</translation>
    </message>
    <message>
        <location line="+69"/>
        <location line="+138"/>
        <source>All Files (*)</source>
        <translation>すべてのファイル (*)</translation>
    </message>
    <message>
        <location line="-97"/>
        <location line="+144"/>
        <source>Error Saving Map</source>
        <translation>マップを保存中にエラー</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>untitled.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>変更が保存されていません</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>変更が保存されていません。保存しますか?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>名前をつけてエクスポート...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>不明のファイルフォーマット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>入力されたファイル名にサポートしている拡張子が含まれていません。</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Cut</source>
        <translation>カット</translation>
    </message>
    <message>
        <location line="+377"/>
        <source>[*]%1 - Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">タイルセットを追加</translation>
    </message>
    <message>
        <location line="-280"/>
        <source>Add External Tileset</source>
        <translation>拡張タイルセットを追加</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiledタイルセットファイル (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>タイルセットを読み込み中にエラー</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>マップ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+123"/>
        <source>%1%</source>
        <translation></translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">タイル・レイヤーの追加</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">オブジェクト・レイヤーの追加</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">レイヤー名:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">新しいレイヤー</translation>
    </message>
    <message>
        <source>%1[*] - Tiled</source>
        <translation type="obsolete">%1[*] - Tiled</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
        <source>untitled.tmx</source>
        <translation type="unfinished">untitled.tmx</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Resize Map</source>
        <translation>マップのリサイズ</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Offset Map</source>
        <translation>マップをずらす</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>タイル・レイヤー %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>オブジェクト・レイヤー %1</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Copy of %1</source>
        <translation>%1をコピー</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>レイヤーの複製</translation>
    </message>
    <message>
        <location line="+120"/>
        <source>Tile</source>
        <translation type="unfinished">タイル</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+100"/>
        <source>Select &amp;All</source>
        <translation>すべて選択(&amp;A)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>すべて選択解除(&amp;N)</translation>
    </message>
    <message>
        <location line="-56"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Add &amp;Tile Layer...</source>
        <translation>タイル・レイヤーを追加(&amp;T)...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer...</source>
        <translation>オブジェクト・レイヤーの追加(&amp;O)...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Duplicate Layer</source>
        <translation>レイヤーの複製(&amp;D)</translation>
    </message>
    <message>
        <location line="-54"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>&amp;Remove Layer</source>
        <translation>レイヤーを削除(&amp;R)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Move Layer &amp;Up</source>
        <translation>レイヤーの順番を上げる(&amp;U)</translation>
    </message>
    <message>
        <location line="-47"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Move Layer Dow&amp;n</source>
        <translation>レイヤーの順番を下げる(&amp;n)</translation>
    </message>
    <message>
        <location line="-43"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Layer &amp;Properties...</source>
        <translation>レイヤーの設定(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>タイル・レイヤー1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>タイルセットの画像 &apos;%1&apos; の読み込みに失敗.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>タイルセットの画像に１つもタイルがありません（画像サイズ、マージン、スペースを考慮した結果）!</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>タイルセットの画像</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>オブジェクト・レイヤー</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>色:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>オブジェクト</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">名前:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">種類:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Change Object</source>
        <translation>オブジェクトを変更</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
        <location line="+135"/>
        <source>Select Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-132"/>
        <location line="+133"/>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location line="+77"/>
        <location line="+145"/>
        <source>Duplicate %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-144"/>
        <location line="+162"/>
        <source>Remove %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-153"/>
        <location line="+163"/>
        <source>Move %n Object(s) to Layer</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="-153"/>
        <source>Object &amp;Properties...</source>
        <translation type="unfinished">オブジェクトのプロパティ(&amp;P)...</translation>
    </message>
    <message numerus="yes">
        <location line="+107"/>
        <source>Move %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>システム標準</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
        <source>%1 Properties</source>
        <translation>%1 プロパティ</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>レイヤー</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;新しいプロパティ&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>画像で保存</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 は既に存在します。
上書きしてよろしいですか?</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>選択範囲</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - 四角形: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+279"/>
        <source>Stamp Brush</source>
        <translation>スタンプ</translation>
    </message>
    <message>
        <location line="-276"/>
        <location line="+277"/>
        <source>B</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
        <source>Remove Tileset</source>
        <translation>タイルセットを削除</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>タイルセット &quot;%1&quot;はまだマップで使われています!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>このタイルセットを削除し、タイル使用部分をすべて取り除いてよろしいですか?</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Tilesets</source>
        <translation>タイルセット</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">プロパティ...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
        <source>Tile &amp;Properties...</source>
        <translation>タイルの設定(&amp;P)...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>タイルセットを名前をつけてエクスポート(&amp;E)...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>タイルセットをインポート(&amp;I)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Tile</source>
        <translation>タイル</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>タイルセットをエクスポート</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiledタイルセットファイル (*.tsx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;empty&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>コリジョン・レイヤーが複数存在します!</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>コリジョン・レイヤーが見つかりません!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>書き込み用ファイルを開けませんでした.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>TMW-eAthena collision files (*.wlk)</translation>
    </message>
    <message>
        <source>TMW-eAthena collision files 2 (*.wlk2)</source>
        <translation type="obsolete">TMW-eAthena collision files 2 (*.wlk2)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">書き込み用ファイルを開けませんでした.</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Tiledマップファイル (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">マップファイルではありません。</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">タイルセットファイルではありません。</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

行 %1, 位置 %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">ファイルは見つかりませんでした: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">読み込めませんでした: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">マップの回転がサポートされていないものです: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">タイルセットのパラメータが不正です &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">タイルセットを読み込み中のエラーが発生しました &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">タイルのIDが不正です: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">タイルセットの画像を読み込み中にエラーが発生しました:
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">&lt;tile&gt; 要素が多すぎます</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">不正なタイル: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">エンコーディングがよく分かりません: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">&apos;%1&apos;という圧縮方法には対応していません</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">レイヤー &apos;%1&apos; のデータが壊れています</translation>
    </message>
    <message>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="obsolete">レイヤー &apos;%3&apos;の(%1,%2)のタイルをパースできません</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">グローバル・タイルIDが不正です (0未満): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">タイルセットが指定されていません</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
        <source>TMX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>レイヤーを追加</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>レイヤーを削除</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+76"/>
        <source>Add Object</source>
        <translation>オブジェクトを追加</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Remove Object</source>
        <translation>オブジェクトを削除</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>オブジェクトを変更</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>オブジェクト・レイヤーのプロパティを変更</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>%1 プロパティを変更</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>選択を変更</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>消去</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>塗りつぶし</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Move Layer Down</source>
        <translation>レイヤーを下に移動</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Move Layer Up</source>
        <translation>レイヤーを上に移動</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>オブジェクトを移動</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>レイヤーをずらす</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>ペイント</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>レイヤー名を変更</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>レイヤーをリサイズ</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>マップをリサイズ</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>オブジェクトをリサイズ</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>タイルセットを追加</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>タイルセットを削除</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>タイルセットを移動</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
        <source>Import Tileset</source>
        <translation>タイルセットをインポート</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>タイルセットをエクスポート</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>画像ファイル</translation>
    </message>
</context>
</TS>
